@@ -17,6 +17,7 @@ from .fromgeometry import from_point2d, from_vector2d, from_ray2d, \
     from_point3d, from_vector3d, from_ray3d, from_plane, \
     from_arc3d, from_polyline3d, from_mesh3d, from_face3d, from_polyface3d, \
     from_sphere, from_cone, from_cylinder
+from .bakeobjects import bake_visualization_set
 
 try:
     import Rhino.Geometry as rg
@@ -44,22 +45,29 @@ class VisualizationSetConduit(rd.DisplayConduit):
         display = drawEventArgs.Display
 
         # for each object to be rendered, pass the drawing arguments
-        for draw_args in self.vis_con.draw_3d_text:
-            display.Draw3dText(*draw_args)
         for draw_args in self.vis_con.draw_mesh_false_colors:
             display.DrawMeshFalseColors(draw_args)
-        for draw_args in self.vis_con.draw_mesh_wires:
-            display.DrawMeshWires(*draw_args)
         for draw_args in self.vis_con.draw_mesh_shaded:
             display.DrawMeshShaded(*draw_args)
+        for draw_args in self.vis_con.draw_brep_shaded:
+            display.DrawBrepShaded(*draw_args)
+
+    def PostDrawObjects(self, drawEventArgs):
+        """Overwrite the method that draws the objects in the display."""
+        # get the DisplayPipeline from the event arguments
+        display = drawEventArgs.Display
+
+        # for each object to be rendered, pass the drawing arguments
+        for draw_args in self.vis_con.draw_3d_text:
+            display.Draw3dText(*draw_args)
+        for draw_args in self.vis_con.draw_mesh_wires:
+            display.DrawMeshWires(*draw_args)
         for draw_args in self.vis_con.draw_mesh_vertices:
             display.DrawMeshVertices(*draw_args)
         for draw_args in self.vis_con.draw_point:
             display.DrawPoint(*draw_args)
         for draw_args in self.vis_con.draw_arrow:
             display.DrawArrow(*draw_args)
-        for draw_args in self.vis_con.draw_brep_shaded:
-            display.DrawBrepShaded(*draw_args)
         for draw_args in self.vis_con.draw_brep_wires:
             display.DrawBrepWires(*draw_args)
         for draw_args in self.vis_con.draw_line:
@@ -646,3 +654,7 @@ class VisualizationSetConverter(object):
             trans = (args[1].Transparency for args in self.draw_mesh_shaded)
             self.draw_mesh_shaded = \
                 [a for _, a in sorted(zip(trans, self.draw_mesh_shaded))]
+
+    def ToString(self):
+        """Overwrite .NET ToString method."""
+        return 'VisualizationSet Converter'
